@@ -24,22 +24,19 @@ logging.basicConfig(level=logging.DEBUG)
 try:
     import saga
 except:
-    logging.warning("SAGA could not be found. Not all functionalities working")
+    logging.debug("SAGA not imported. ")
 
-sys.path.append(os.path.dirname(os.path.abspath(__file__)) + "/../../ext/threadpool-1.2.7/src/")
 logging.debug(str(sys.path))
 from threadpool import *
 
 # BigJob/Pilot framework classes
 from bigjob import logger
-from pilot.impl.pilotdata_manager import PilotData, PilotDataService
+from pilot.impl.pilotdata_manager import PilotData, DataUnit, PilotDataService
 
 logger.debug("Python Version: " + str(sys.version_info))
 if sys.version_info < (2, 5):
-    sys.path.append(os.path.dirname( __file__ ) + "/../../ext/uuid-1.30/")
     sys.stderr.write("Warning: Using unsupported Python version\n")
 if sys.version_info < (2, 4):
-    sys.path.append(os.path.dirname( __file__ ) + "/../../ext/subprocess-2.6.4/")
     sys.stderr.write("Warning: Using unsupported Python version\n")
 if sys.version_info < (2, 3):
     sys.stderr.write("Warning: Python versions <2.3 not supported\n")
@@ -314,6 +311,8 @@ class bigjob_agent:
                     logger.debug("Environment: " + str(env_list))
                     for i in env_list:
                         logger.debug("Eval " + i)
+                        # Hack for conduction experiments on Kraken
+                        # Kraken specific support for running n sub-jobs at a time
                         if i.startswith("NUMBER_SUBJOBS"):
                             self.number_subjobs=int(i.split("=")[1].strip())
                             logger.debug("NUMBER_SUBJOBS: " + str(self.number_subjobs))
@@ -407,7 +406,7 @@ class bigjob_agent:
                     #command ="chmod +x " + executable +";export PATH=$PATH:" + workingdirectory + ";" +command                    
                 else:
                     # Environment variables need to be handled later!
-                    command =  executable + " " + arguments
+                    command =  envi + executable + " " + arguments
                 
                 # special setup for MPI NAMD jobs
                 machinefile = self.allocate_nodes(job_dict)
@@ -686,10 +685,12 @@ class bigjob_agent:
     def start_background_thread(self):        
         self.stop=False                
         logger.debug("##################################### New POLL/MONITOR cycle ##################################")
-        logger.debug("Free nodes: " + str(len(self.freenodes)) + " Busy Nodes: " + str(len(self.busynodes)))
         while True and self.stop==False:
+            logger.debug("Free nodes: " + str(len(self.freenodes)) 
+                        + " Busy Nodes: " + str(len(self.busynodes))
+                        + " Number of running sub-jobs: " + str(len(self.jobs)))
             if self.is_stopped(self.base_url)==True:
-                logger.debug("Pilot job entry deleted - terminate agent")
+                logger.debug("Pilot terminated.")
                 break
             else:
                 logger.debug("Pilot job entry: " + str(self.base_url) + " exists. Pilot job not in state stopped.")
@@ -732,10 +733,13 @@ class bigjob_agent:
         """ stage in data units specified in input_data field """
         logger.debug("Stage in input files to: %s"%target_directory)
         for i in input_data:
-            pd_url = self.__get_pd_url(i)
-            du_id = self.__get_du_id(i)
-            pd = PilotData(pd_url=pd_url)
-            du = pd.get_du(du_id)
+            #pd_url = self.__get_pd_url(i)
+            #du_id = self.__get_du_id(i)
+            #pd = PilotData(pd_url=pd_url)
+            #du = pd.get_du(du_id)
+            #du.export(target_directory)
+            du = DataUnit(du_url=i)
+            du.wait()
             du.export(target_directory)
     
     
@@ -757,10 +761,10 @@ class bigjob_agent:
         for data_unit_dict in output_data: 
             logger.debug("Process: " + str(data_unit_dict))
             for du_url in data_unit_dict.keys(): # go through all dicts (each representing 1 PD) 
-                pd_url = self.__get_pd_url(du_url)
-                du_id = self.__get_du_id(du_url)
-                pilot_data = PilotData(pd_url=pd_url)
-                du = pilot_data.get_du(du_id)
+                #pd_url = self.__get_pd_url(du_url)
+                #pilot_data = PilotData(pd_url=pd_url)
+                #du = pilot_data.get_du(du_url)
+                du = DataUnit(du_url=du_url)
                 file_list = data_unit_dict[du_url]
                 logger.debug("Add files: " + str(file_list))
                 all_files=[]
